function mm = MassMatrix(X)

if ~isvector(X) || ~isnumeric(X) || ~isreal(X) || length(X) < 2
  ME = MException('MassMatrix:InconsistentArguments','X must be a real vector');
  throw(ME);
end

if ~all(diff(X)>0)
  ME = MException('MassMatrix:InconsistentArguments','X must be a monotonically increasing vector');
  throw(ME);
end

dX = diff(X);
n = length(dX);

% diagonal elements
mm = zeros(n+1,n+1);
mm(1,1) = 1/3*dX(1);
mm(n+1,n+1) = 1/3*dX(n);
for i=1:(n-1)
  mm(i+1,i+1) = 1/3*(dX(i)+dX(i+1));
end

% subdiagonal & superdiagonal elements
for i=1:n
  mm(i+1,i) = 1/6*dX(i);
  mm(i,i+1) = 1/6*dX(i);
end
