function sm = StiffnessMatrix(X)

if ~isvector(X) || ~isnumeric(X) || ~isreal(X) || length(X) < 2
  ME = MException('StiffnessMatrix:InconsistentArguments','X must be a real vector');
  throw(ME);
end

if ~all(diff(X)>0)
  ME = MException('StiffnessMatrix:InconsistentArguments','X must be a monotonically increasing vector');
  throw(ME);
end

recdX = 1./diff(X);
n = length(recdX);

% diagonal elements
sm = zeros(n+1,n+1);
sm(1,1) = recdX(1);
sm(n+1,n+1) = recdX(n);
for i=1:(n-1)
  sm(i+1,i+1) = recdX(i)+recdX(i+1);
end

% subdiagonal & superdiagonal elements
for i=1:n
  sm(i+1,i) = -recdX(i);
  sm(i,i+1) = -recdX(i);
end
