function [u] = ellipticsolver(geometryfunction,a,c,f,boundaryfunction,varargin)
% -au_{xx}+cu = f

[p,e,t] = initmesh(geometryfunction,varargin{:});

function [qmatrix,gmatrix,hmatrix,rmatrix] = dirichlet(p,e,bc) % Dirichlet boundary conditionsd
  ne = size(e,2); % number of edges
  qmatrix = zeros(1,ne);
  gmatrix = zeros(1,ne);
  hmatrix = ones(1,2*ne);
  rmatrix = zeros(1,2*ne);

  for k = 1:ne
    x1 = p(1,e(1,k)); % x at first point in segment
    x2 = p(1,e(2,k)); % x at second point in segment
    y1 = p(2,e(1,k)); % y at first point in segment
    y2 = p(2,e(2,k)); % y at second point in segment
    switch e(5,k)
      otherwise % all boundaries
        rmatrix(k) = bc(x1,y1); % boundary value at first point
        rmatrix(k+ne) = bc(x2,y2); % boundary value at second point
    end
  end
end

pdebound = @(p,e,u,time) dirichlet(p,e,boundaryfunction);

u = assempde(pdebound,p,e,t,a,c,f);
pdesurf(p,t,u)
axis vis3d

end
