function [u] = ellipticsolver(geometryfunction,a,c,f,d,boundaryfunction,u0function,tmax,varargin)
% du_t-au_{xx}+cu = f

N = 100;
tlist = [0:tmax/N:tmax];

[p,e,t] = initmesh(geometryfunction,varargin{:});

np = size(p,2);
u0 = zeros(np,1);
for k = 1:np
  x = p(1,k); % x coordinate of the point
  y = p(2,k); % y coordinate of the point
  u0(k) = u0function(x,y); % set initial values
end

function [qmatrix,gmatrix,hmatrix,rmatrix] = dirichlet(p,e,bc) % Dirichlet boundary conditionsd
  ne = size(e,2); % number of edges
  qmatrix = zeros(1,ne);
  gmatrix = zeros(1,ne);
  hmatrix = ones(1,2*ne);
  rmatrix = zeros(1,2*ne);

  for k = 1:ne
    x1 = p(1,e(1,k)); % x at first point in segment
    x2 = p(1,e(2,k)); % x at second point in segment
    y1 = p(2,e(1,k)); % y at first point in segment
    y2 = p(2,e(2,k)); % y at second point in segment
    switch e(5,k)
      otherwise % all boundaries
        rmatrix(k) = bc(x1,y1); % boundary value at first point
        rmatrix(k+ne) = bc(x2,y2); % boundary value at second point
    end
  end
end

pdebound = @(p,e,u,time) dirichlet(p,e,boundaryfunction);

u = parabolic(u0,tlist,pdebound,p,e,t,a,c,f,d); % solve pde

limits = zeros(1,6);
limits(1) = min(p(1,:));
limits(2) = max(p(1,:));
limits(3) = min(p(2,:));
limits(4) = max(p(2,:));
limits(5) = min(min(u));
limits(6) = max(max(u));
for k = 1:(N+1)
  pdesurf(p,t,u(:,k)) % plot solution
  axis(limits)
  if k == 1
    pause(0.3)
  end
  pause(0.01)
end

end
